==> ejc-guarantee-api-3.0.0-20230629.012854-37-sources.jar: com/ejianc/business/guarantee/relieve/vo/ContractRelieveVO.java <==
package com.ejianc.business.guarantee.relieve.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 担保合同解保
 * 
 * @author generator
 * 
 */
public class ContractRelieveVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String relieveRemark; // 解保备注
    private BigDecimal premiumMny; // 保费金额
    private BigDecimal premiumTaxMny; // 保费金额(含税)
    private Long contractId; // 担保合同id
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date relieveDate;//解保日期
    private String contractName; // 合同名称
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String relieveName;//解保名称


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRelieveRemark() {
        return relieveRemark;
    }

    public void setRelieveRemark(String relieveRemark) {
        this.relieveRemark = relieveRemark;
    }

    public BigDecimal getPremiumMny() {
        return premiumMny;
    }

    public void setPremiumMny(BigDecimal premiumMny) {
        this.premiumMny = premiumMny;
    }
    public BigDecimal getPremiumTaxMny() {
        return premiumTaxMny;
    }

    public void setPremiumTaxMny(BigDecimal premiumTaxMny) {
        this.premiumTaxMny = premiumTaxMny;
    }
    @ReferSerialTransfer(referCode="ref-guarantee-contract")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Date getRelieveDate() {
        return relieveDate;
    }

    public void setRelieveDate(Date relieveDate) {
        this.relieveDate = relieveDate;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getRelieveName() {
        return relieveName;
    }

    public void setRelieveName(String relieveName) {
        this.relieveName = relieveName;
    }
}

==> ejc-guarantee-api-3.0.0-20240812.091707-71-sources.jar: com/ejianc/business/guarantee/relieve/vo/ContractRelieveVO.java <==
package com.ejianc.business.guarantee.relieve.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 担保合同解保
 * 
 * @author generator
 * 
 */
public class ContractRelieveVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String relieveRemark; // 解保备注
    private BigDecimal premiumMny; // 保费金额
    private BigDecimal premiumTaxMny; // 保费金额(含税)
    private Long contractId; // 担保合同id
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date relieveDate;//解保日期
    private String contractName; // 合同名称
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String relieveName;//解保名称
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date approveDate; //审批通过时间

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRelieveRemark() {
        return relieveRemark;
    }

    public void setRelieveRemark(String relieveRemark) {
        this.relieveRemark = relieveRemark;
    }

    public BigDecimal getPremiumMny() {
        return premiumMny;
    }

    public void setPremiumMny(BigDecimal premiumMny) {
        this.premiumMny = premiumMny;
    }
    public BigDecimal getPremiumTaxMny() {
        return premiumTaxMny;
    }

    public void setPremiumTaxMny(BigDecimal premiumTaxMny) {
        this.premiumTaxMny = premiumTaxMny;
    }
    @ReferSerialTransfer(referCode="ref-guarantee-contract")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Date getRelieveDate() {
        return relieveDate;
    }

    public void setRelieveDate(Date relieveDate) {
        this.relieveDate = relieveDate;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getRelieveName() {
        return relieveName;
    }

    public void setRelieveName(String relieveName) {
        this.relieveName = relieveName;
    }

    public Date getApproveDate() {
        return approveDate;
    }

    public void setApproveDate(Date approveDate) {
        this.approveDate = approveDate;
    }
}
